/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.aries.application.resolver.obr.impl;

import java.util.Map;

import org.apache.felix.bundlerepository.Capability;
import org.apache.felix.bundlerepository.Requirement;
import org.apache.felix.bundlerepository.Resource;
import org.osgi.framework.Version;

/**
 * @version $Rev: 964138 $ $Date: 2010-07-14 21:03:40 +0200 (Wed, 14 Jul 2010) $
 */
public class ResourceWrapper implements Resource {

    private final Resource resource;
    
    public ResourceWrapper(Resource resource) {
        this.resource = resource;
    }
    
    public Capability[] getCapabilities() {
        return resource.getCapabilities();
    }

    public String[] getCategories() {
        return resource.getCategories();
    }

    public String getId() {
        return resource.getId();
    }

    public String getPresentationName() {
        return resource.getPresentationName();
    }

    public Map getProperties() {
        return resource.getProperties();
    }

    public Requirement[] getRequirements() {
        return resource.getRequirements();
    }

    public Long getSize() {
        return resource.getSize();
    }

    public String getSymbolicName() {
        return resource.getSymbolicName();
    }

    public String getURI() {
        return resource.getURI();
    }

    public Version getVersion() {
        return resource.getVersion();
    }

    public boolean isLocal() {
        return false;
    }

}
